@@ -12,7 +12,9 @@
 # 
 #-------------------------------------------------------------------------------
 
-from enthought.traits.api import HasTraits, Instance, Int
+from __future__ import absolute_import
+
+from ..api import HasTraits, Instance, Int
 
 import unittest
 
