@@ -2,14 +2,14 @@
 #
 #  Copyright (c) 2007, Enthought, Inc.
 #  All rights reserved.
-# 
+#
 #  This software is provided without warranty under the terms of the BSD
 #  license included in /LICENSE.txt and may be redistributed only
 #  under the conditions described in the aforementioned license.  The license
 #  is also available online at http://www.enthought.com/licenses/BSD.txt
 #
 #  Thanks for using Enthought open source!
-# 
+#
 #-------------------------------------------------------------------------------
 
 
@@ -17,13 +17,14 @@
 """ Test whether HasTraits objects with cycles can be garbage collected.
 """
 
-# Standard library imports
+from __future__ import absolute_import
+
 import gc
 import time
 import unittest
 
 # Enthought library imports
-from enthought.traits.api import HasTraits, Any
+from ..api import HasTraits, Any, DelegatesTo, Instance, Int
 
 class TestCase(unittest.TestCase):
     def _simple_cycle_helper(self, foo_class):
@@ -104,5 +105,34 @@ class TestCase(unittest.TestCase):
         self.assertTrue(len(referrers) > 0)
         self.assertTrue(foo in referrers)
 
+    def test_delegates_to(self):
+        """ Tests if an object that delegates to another is freed. 
+        """
+        class Base(HasTraits):
+            """ Object we are delegating to. """
+
+            i = Int
+
+
+        class Delegates(HasTraits):
+            """ Object that delegates. """
+
+            b = Instance(Base)
+
+            i = DelegatesTo('b')
+
+        # Make a pair of object
+        b = Base()
+        d = Delegates(b=b)
+
+        # Delete d and thoroughly collect garbage
+        del d
+        for i in range(3):
+            gc.collect(2)
+
+        # See if we still have a Delegates
+        ds = [ obj for obj in gc.get_objects() if isinstance(obj, Delegates) ]
+        self.assert_(ds == [])
+
 if __name__ == '__main__':
     unittest.main()
