@@ -23,36 +23,21 @@
 #  Imports:
 #-------------------------------------------------------------------------------
 
+from __future__ import absolute_import
+
 import re
 import string
 import weakref
+from weakref import WeakKeyDictionary
+from string import whitespace
+from types import MethodType
 
-from string \
-    import whitespace
-    
-from weakref \
-    import WeakKeyDictionary
-    
-from types \
-    import MethodType
-
-from has_traits \
-    import HasTraits, HasPrivateTraits
-    
-from trait_base \
-    import Undefined, Uninitialized
-    
-from traits \
-    import Property
-    
-from trait_types \
-    import Str, Int, Bool, Instance, List, Enum, Any
-
-from trait_errors \
-    import TraitError
-    
-from trait_notifiers \
-   import TraitChangeNotifyWrapper
+from .has_traits import HasPrivateTraits
+from .trait_base import Undefined, Uninitialized
+from .traits import Property
+from .trait_types import Str, Int, Bool, Instance, List, Enum, Any
+from .trait_errors import TraitError
+from .trait_notifiers import TraitChangeNotifyWrapper
 
 #---------------------------------------------------------------------------
 #  Constants:  
@@ -95,9 +80,6 @@ ListenerType = {
 # Invalid destination ( object, name ) reference marker (i.e. ambiguous):
 INVALID_DESTINATION = ( None, None )
 
-# Invalid objects for unregistering:
-InvalidObjects = ( None, Uninitialized )
-
 # Regular expressions used by the parser:
 simple_pat = re.compile( r'^([a-zA-Z_]\w*)(\.|:)([a-zA-Z_]\w*)$' )
 name_pat   = re.compile( r'([a-zA-Z_]\w*)\s*(.*)' )
@@ -308,7 +290,7 @@ class ListenerItem ( ListenerBase ):
     # listener, one of: (SIMPLE_LISTENER, LIST_LISTENER, DICT_LISTENER).
     active = Instance( WeakKeyDictionary, () )
     
-    #-- 'ListenerBase' Class Method Implementations ----------------------------            
+    #-- 'ListenerBase' Class Method Implementations ----------------------------
 
     #---------------------------------------------------------------------------
     #  String representation:
@@ -462,7 +444,7 @@ class ListenerItem ( ListenerBase ):
     def unregister ( self, old ):
         """ Unregisters any existing listeners.
         """
-        if old not in InvalidObjects:
+        if old is not None and old is not Uninitialized:
             try:
                 active = self.active.pop( old, None )
                 if active is not None:
@@ -505,7 +487,7 @@ class ListenerItem ( ListenerBase ):
     def handle_list ( self, object, name, old, new ):
         """ Handles a trait change for a list (or set) trait.
         """
-        if old not in InvalidObjects:
+        if old is not None and old is not Uninitialized:
             unregister = self.next.unregister
             for obj in old:
                 unregister( obj )
@@ -556,6 +538,8 @@ class ListenerItem ( ListenerBase ):
                 
         if len( new.changed ) > 0:
             dict = getattr( object, name )
+            unregister = self.next.unregister
+            register = self.next.register
             for key, obj in new.changed.items():
                 unregister( obj )
                 register( dict[ key ] )
@@ -569,10 +553,10 @@ class ListenerItem ( ListenerBase ):
         """ Handles an invalid intermediate trait change to a handler that must 
             be applied to the final destination object.trait.
         """
-        if old not in InvalidObjects:
+        if old is not None and old is not Uninitialized:
             raise TraitError( "on_trait_change handler signature is "
                               "incompatible with a change to an intermediate trait" )
-                
+
     #-- Event Handlers ---------------------------------------------------------
     
     #---------------------------------------------------------------------------
@@ -766,7 +750,7 @@ class ListenerItem ( ListenerBase ):
     # the behavior of sets ever diverges from that of lists, then this code may
     # need to be changed.
     _register_set = _register_list
-        
+
     #---------------------------------------------------------------------------
     #  Registers a handler for a dictionary trait:
     #---------------------------------------------------------------------------
@@ -814,7 +798,7 @@ class ListenerItem ( ListenerBase ):
                                  remove   = remove, 
                                  dispatch = self.dispatch,
                                  priority = self.priority )
-            
+
         object._on_trait_change( tl_handler_items, name + '_items', 
                                  remove   = remove, 
                                  dispatch = self.dispatch,
@@ -935,7 +919,7 @@ class ListenerGroup ( ListenerBase ):
                 item.dispatch = dispatch
             
     #-- 'ListenerBase' Class Method Implementations ----------------------------            
-   
+
     #---------------------------------------------------------------------------
     #  String representation:
     #---------------------------------------------------------------------------
@@ -1220,9 +1204,9 @@ class ListenerNotifyWrapper ( TraitChangeNotifyWrapper ):
     
     #-- TraitChangeNotifyWrapper Method Overrides ------------------------------
     
-    def __init__ ( self, handler, owner, id, listener ):
+    def __init__ ( self, handler, owner, id, listener, target=None):
         self.type     = ListenerType.get( self.init( handler, 
-                                    weakref.ref( owner, self.owner_deleted ) ) )
+                                    weakref.ref( owner, self.owner_deleted ), target ) )
         self.id       = id
         self.listener = listener
     
