@@ -18,8 +18,10 @@
 #-------------------------------------------------------------------------------
 #  Imports:
 #-------------------------------------------------------------------------------
-from file_editor \
-    import ToolkitEditorFactory as EditorFactory
+
+from __future__ import absolute_import
+
+from .file_editor import ToolkitEditorFactory as EditorFactory
 
 #-------------------------------------------------------------------------------
 #  'ToolkitEditorFactory' class:
@@ -33,4 +35,4 @@ class ToolkitEditorFactory ( EditorFactory ):
 # Define the DirectoryEditor class
 DirectoryEditor = ToolkitEditorFactory
 
-### EOF #######################################################################
\ No newline at end of file
+### EOF #######################################################################
