@@ -24,11 +24,11 @@
 #  Imports:
 #-------------------------------------------------------------------------------
 
-from color_editor \
-    import ToolkitEditorFactory as EditorFactory
+from __future__ import absolute_import
 
-from enthought.traits.ui.toolkit \
-    import toolkit_object
+from .color_editor import ToolkitEditorFactory as EditorFactory
+
+from ..toolkit import toolkit_object
 
 #-------------------------------------------------------------------------------
 #  'ToolkitEditorFactory' class:
@@ -60,4 +60,4 @@ def RGBColorEditor(*args, **traits):
        return toolkit_object('rgb_color_editor:ToolkitEditorFactory', True)(
                                                             *args, **traits)
     except:
-       return ToolkitEditorFactory(*args, **traits)
\ No newline at end of file
+       return ToolkitEditorFactory(*args, **traits)
