@@ -22,58 +22,56 @@
 #  Imports:
 #-------------------------------------------------------------------------------
 
-from enthought.traits.api \
-    import Float, Color, Property
-    
-from enthought.traits.ui.ui_traits \
-    import Alignment
-    
-from enthought.traits.ui.basic_editor_factory \
-    import BasicEditorFactory
+from __future__ import absolute_import
+
+from ...api import Float, Color, Property
+
+from ..ui_traits import Alignment
+
+from ..basic_editor_factory import BasicEditorFactory
+
+from ..toolkit import toolkit_object
 
-from enthought.traits.ui.toolkit \
-    import toolkit_object
-                     
 #-------------------------------------------------------------------------------
 #  Create the editor factory object:
 #-------------------------------------------------------------------------------
 
 # Editor factory for scrubber-based integer or float value editors.
 class ScrubberEditor ( BasicEditorFactory ):
-    
+
     # The editor class to be instantiated:
     klass = Property
-    
+
     # The low end of the scrubber range:
     low = Float
-    
+
     # The high end of the scrubber range:
     high = Float
-    
+
     # The normal increment (default: auto-calculate):
     increment = Float
-    
+
     # The alignment of the text within the scrubber:
     alignment = Alignment( 'center' )
-    
+
     # The background color for the scrubber:
     color = Color( None )
-    
+
     # The hover mode background color for the scrubber:
     hover_color = Color( None )
-    
+
     # The active mode background color for the scrubber:
     active_color = Color( None )
-    
+
     # The scrubber border color:
     border_color = Color( None )
-    
+
     # The color to use for the value text:
     text_color = Color( 'black' )
-    
+
     def _get_klass(self):
         """ Returns the toolkit-specific editor class to be instantiated.
         """
         return toolkit_object('scrubber_editor:_ScrubberEditor')
 
-### EOF ##################################################################
\ No newline at end of file
+### EOF ##################################################################
