@@ -21,32 +21,34 @@
 #  Imports:
 #-------------------------------------------------------------------------------
 
-from enthought.traits.api \
-    import Int, Float, List, Instance, Str, Color, Font, Any, Tuple, Dict, \
-            Enum, Trait, Bool, Callable, Range
+from __future__ import absolute_import
 
-# CIRCULAR IMPORT FIXME: Importing from the source rather than traits.ui.api
-# to avoid circular imports, as this EditorFactory will be part of
-# traits.ui.api as well.
-from enthought.traits.ui.view \
-    import View
+from ...api import (Int, Float, List, Instance, Str, Color, Font, Any, Tuple,
+        Dict, Enum, Trait, Bool, Callable, Range, on_trait_change)
 
-from enthought.traits.ui.item \
-    import Item
+from ..editor_factory import EditorFactory
 
-from enthought.traits.ui.handler \
-    import Handler
+from ..handler import Handler
 
-from enthought.traits.ui.ui_traits \
-    import AView
+from ..helper import Orientation
 
-from enthought.traits.ui.editor_factory \
-    import EditorFactory
+from ..item import Item
 
-from enthought.traits.ui.helper \
-    import Orientation
+from ..table_filter import TableFilter
 
-from enum_editor import EnumEditor
+from ..ui_traits import AView
+
+from ..view import View
+
+from .enum_editor import EnumEditor
+
+#-------------------------------------------------------------------------------
+#  Constants:
+#-------------------------------------------------------------------------------
+
+# The filter used to indicate that the user wants to customize the current
+# filter
+customize_filter = TableFilter( name = 'Customize...' )
 
 #-------------------------------------------------------------------------------
 #  Trait definitions:
@@ -171,6 +173,9 @@ class ToolkitEditorFactory ( EditorFactory ):
     # Show column labels?
     show_column_labels = Bool( True )
 
+    # Show row labels?
+    show_row_labels = Bool( False )
+
     # Font to use for text in cells
     cell_font = Font
 
@@ -201,15 +206,6 @@ class ToolkitEditorFactory ( EditorFactory ):
     # Background color of selected item
     selection_bg_color = Color( 'light blue', allow_none = True )
 
-    # The theme to use for normal cells:
-    cell_theme = Any
-
-    # The theme to use for alternate row cells (defaults to 'cell_theme):
-    alt_theme = Any
-
-    # The theme to use for selected cells:
-    selected_theme = Any
-
     # Color of selected text
     selection_color = Color( 'black' )
 
@@ -352,7 +348,7 @@ class ToolkitEditorFactory ( EditorFactory ):
         # NOTE: We are initializing the 'cell_bg_color' trait in this method
         # instead of in the trait definition so as to delay importing from
         # ui.api until needed (will lead to circular imports otherwise).
-        from enthought.traits.ui.api import WindowColor
+        from ..api import WindowColor
         return WindowColor
 
     def _label_bg_color_default(self):
@@ -361,10 +357,195 @@ class ToolkitEditorFactory ( EditorFactory ):
         # NOTE: We are initializing the 'cell_bg_color' trait in this method
         # instead of in the trait definition so as to delay importing from
         # ui.api until needed (will lead to circular imports otherwise).
-        from enthought.traits.ui.api import WindowColor
+        from ..api import WindowColor
         return WindowColor
 
+    #---------------------------------------------------------------------------
+    #  Event handlers:
+    #---------------------------------------------------------------------------
+
+    @on_trait_change('filters[]')
+    def _update_filter_editor ( self, object, name, old, new ):
+        """ Handles the set of filters associated with the editor's factory 
+            being changed.
+        """
+        values = { None: '000:No filter' }
+        i      = 0
+        for filter in self.filters:
+            if not filter.template:
+                i += 1
+                values[ filter ] = '%03d:%s' % ( i, filter.name )
+        values[ customize_filter ] = '%03d:%s' % ( (i + 1),
+                                                   customize_filter.name )
+        if self._filter_editor is None:
+            self._filter_editor = EnumEditor( values = values )
+        else:
+            self._filter_editor.values = values
+
+
 # Define the TableEditor class
 TableEditor = ToolkitEditorFactory
 
-### EOF ---------------------------------------------------------------------
+#-------------------------------------------------------------------------------
+#  Base class for toolkit-specific editors
+#-------------------------------------------------------------------------------
+
+class BaseTableEditor(object):
+    """ Base class for toolkit-specific editors.
+    """
+
+    #---------------------------------------------------------------------------
+    #  Interface for toolkit-specific editors:
+    #---------------------------------------------------------------------------
+
+    def set_menu_context ( self, selection, object, column ):
+        """Call before creating a context menu for a cell, then set self as the
+           controller for the menu.
+        """
+        self._menu_context = { 'selection': selection,
+                               'object':    object,
+                               'column':    column,
+                               'editor':    self,
+                               'info':      self.ui.info,
+                               'handler':   self.ui.handler }
+
+    #---------------------------------------------------------------------------
+    #  pyface.action 'controller' interface implementation:
+    #---------------------------------------------------------------------------
+
+    def add_to_menu ( self, menu_item ):
+        """ Adds a menu item to the menu bar being constructed.
+        """
+        action = menu_item.item.action
+        self.eval_when( action.enabled_when, menu_item, 'enabled' )
+        self.eval_when( action.checked_when, menu_item, 'checked' )
+
+    def add_to_toolbar ( self, toolbar_item ):
+        """ Adds a toolbar item to the toolbar being constructed.
+        """
+        self.add_to_menu( toolbar_item )
+
+    def can_add_to_menu ( self, action ):
+        """ Returns whether the action should be defined in the user interface.
+        """
+        if action.defined_when != '':
+            if not eval( action.defined_when, globals(), 
+                         self._menu_context ):
+                return False
+
+        if action.visible_when != '':
+            if not eval( action.visible_when, globals(), 
+                         self._menu_context ):
+                return False
+
+        return True
+
+    def can_add_to_toolbar ( self, action ):
+        """ Returns whether the toolbar action should be defined in the user
+            interface.
+        """
+        return self.can_add_to_menu( action )
+
+    def perform ( self, action, action_event = None ):
+        """ Performs the action described by a specified Action object.
+        """
+        self.ui.do_undoable( self._perform, action )
+
+    def _perform ( self, action ):
+        method_name        = action.action
+        info               = self.ui.info
+        handler            = self.ui.handler
+        context            = self._menu_context
+        self._menu_context  = None
+        selection          = context[ 'selection' ]
+
+        if method_name.find( '.' ) >= 0:
+            if method_name.find( '(' ) < 0:
+                method_name += '()'
+            try:
+                eval( method_name, globals(), context )
+            except:
+                # fixme: Should the exception be logged somewhere?
+                pass
+            return
+
+        method = getattr( handler, method_name, None )
+        if method is not None:
+            method( info, selection )
+            return
+
+        if action.on_perform is not None:
+            action.on_perform( selection )
+            return
+
+        action.perform( selection )
+
+    #---------------------------------------------------------------------------
+    #  Menu support methods:
+    #---------------------------------------------------------------------------
+
+    def eval_when ( self, condition, object, trait ):
+        """ Evaluates a condition within a defined context and sets a specified
+        object trait based on the result, which is assumed to be a Boolean.
+        """
+        if condition != '':
+            value = bool( eval( condition, globals(), self._menu_context ) )
+            setattr( object, trait, value )
+
+#-------------------------------------------------------------------------------
+#  Helper class for toolkit-specific editors to implement 'reversed' option:
+#-------------------------------------------------------------------------------
+
+class ReversedList ( object ):
+    """ A list whose order is the reverse of its input.
+    """
+
+    def __init__ ( self, list ):
+        self.list = list
+
+    def insert ( self, index, value ):
+        """ Inserts a value at a specified index in the list.
+        """
+        return self.list.insert( self._index( index - 1 ), value )
+
+    def index ( self, value ):
+        """ Returns the index of the first occurence of the specified value in
+            the list.
+        """
+        list = self.list[:]
+        list.reverse()
+        
+        return list.index( value )
+
+    def __len__ ( self ):
+        """ Returns the length of the list.
+        """
+        return len( self.list )
+
+    def __getitem__ ( self, index ):
+        """ Returns the value at a specified index in the list.
+        """
+        return self.list[ self._index( index ) ]
+
+    def __setslice__ ( self, i, j, values ):
+        """ Sets a slice of a list to the contents of a specified sequence.
+        """
+        return self.list.__setslice__( self._index( i ), self._index( j ),
+                                       values )
+
+    def __delitem__ ( self, index ):
+        """ Deletes the item at a specified index.
+        """
+        return self.list.__delitem__( self._index( index ) )
+
+    def _index ( self, index ):
+        """ Returns the "reversed" value for a specified index.
+        """
+        if index < 0:
+            return (-1 - index)
+            
+        result = (len( self.list ) - index - 1)
+        if result >= 0:
+            return result
+            
+        return index
