@@ -20,20 +20,17 @@
 #  Imports:
 #-------------------------------------------------------------------------------
 
-from enthought.traits.api \
-    import Any, Dict, Bool, Tuple, Int, List, Instance, Str, Enum
+from __future__ import absolute_import
 
-from enthought.traits.ui.tree_node \
-    import TreeNode
+from ...api import Any, Dict, Bool, Tuple, Int, List, Instance, Str, Enum
+
+from ..tree_node import TreeNode
     
-from enthought.traits.ui.dock_window_theme \
-    import DockWindowTheme
+from ..dock_window_theme import DockWindowTheme
 
-from enthought.traits.ui.editor_factory \
-    import EditorFactory
+from ..editor_factory import EditorFactory
 
-from enthought.traits.ui.helper \
-    import Orientation
+from ..helper import Orientation
     
 #-------------------------------------------------------------------------------
 #  Trait definitions:
@@ -62,6 +59,9 @@ class ToolkitEditorFactory ( EditorFactory ):
     # Are the individual nodes editable?
     editable = Bool(True)
 
+    # Selection mode.
+    selection_mode = Enum('single', 'extended')
+
     # Is the editor shared across trees?
     shared_editor = Bool(False)
 
@@ -97,6 +97,9 @@ class ToolkitEditorFactory ( EditorFactory ):
 
     # Called when a node is double-clicked
     on_dclick = Any
+    
+    # Call when the mouse hovers over a node
+    on_hover = Any
 
     # The optional extended trait name of the trait to synchronize with the
     # editor's current selection:
