@@ -2,14 +2,14 @@
 #
 #  Copyright (c) 2006, Enthought, Inc.
 #  All rights reserved.
-# 
+#
 #  This software is provided without warranty under the terms of the BSD
 #  license included in enthought/LICENSE.txt and may be redistributed only
 #  under the conditions described in the aforementioned license.  The license
 #  is also available online at http://www.enthought.com/licenses/BSD.txt
 #
 #  Thanks for using Enthought open source!
-#  
+#
 #  Author: Jason Sugg
 #  Date:   03/28/2006
 #
@@ -22,14 +22,16 @@
 #  Imports:
 #-------------------------------------------------------------------------------
 
-from enthought.etsconfig.api import ETSConfig
+from __future__ import absolute_import
 
-from enthought.traits.ui.table_column import ObjectColumn
+from ....etsconfig.api import ETSConfig
+
+from ..table_column import ObjectColumn
 
 if ETSConfig.toolkit == 'wx':
-    from enthought.pyface.ui.wx.grid.checkbox_renderer import CheckboxRenderer
+    from ....pyface.ui.wx.grid.checkbox_renderer import CheckboxRenderer
 elif ETSConfig.toolkit == 'qt4':
-    from enthought.traits.ui.qt4.extra.checkbox_renderer import CheckboxRenderer
+    from ..qt4.extra.checkbox_renderer import CheckboxRenderer
 else:
     raise NotImplementedError, "No checkbox renderer for backend"
 
@@ -38,11 +40,11 @@ else:
 #-------------------------------------------------------------------------------
 
 class CheckboxColumn ( ObjectColumn ):
-    
+
     #---------------------------------------------------------------------------
-    #  Initializes the object:  
+    #  Initializes the object:
     #---------------------------------------------------------------------------
-        
+
     def __init__ ( self, **traits ):
         """ Initializes the object.
         """
@@ -54,25 +56,25 @@ class CheckboxColumn ( ObjectColumn ):
     #---------------------------------------------------------------------------
     #  Returns the cell background color for the column for a specified object:
     #---------------------------------------------------------------------------
-    
+
     def get_cell_color ( self, object ):
-        """ Returns the cell background color for the column for a specified 
+        """ Returns the cell background color for the column for a specified
             object.
         """
-        
+
         # Override the parent class to ALWAYS provide the standard color:
         return self.cell_color_
 
     #---------------------------------------------------------------------------
-    #  Returns whether the column is editable for a specified object:  
+    #  Returns whether the column is editable for a specified object:
     #---------------------------------------------------------------------------
-                
+
     def is_editable ( self, object ):
         """ Returns whether the column is editable for a specified object.
         """
-        
+
         # Although a checkbox column is always editable, we return this
         # to keep a standard editor from appearing. The editing is handled
         # in the renderer's handlers.
         return False
-        
+
