@@ -2,14 +2,14 @@
 #
 #  Copyright (c) 2005, Enthought, Inc.
 #  All rights reserved.
-#  
+#
 #  This software is provided without warranty under the terms of the BSD
 #  license included in enthought/LICENSE.txt and may be redistributed only
 #  under the conditions described in the aforementioned license.  The license
 #  is also available online at http://www.enthought.com/licenses/BSD.txt
 #
 #  Thanks for using Enthought open source!
-#  
+#
 #  Author: David C. Morrill
 #  Date:   10/25/2004
 #
@@ -23,20 +23,16 @@
 #  Imports:
 #-------------------------------------------------------------------------------
 
-from string \
-    import uppercase, lowercase
+from __future__ import absolute_import
 
-    
-from enthought.traits.api \
-    import HasPrivateTraits, Enum, Trait, CTrait, Instance, Str, Any, Int, \
-           Event, Bool, BaseTraitHandler, TraitError
-    
-from enthought.traits.ui.ui_traits \
-    import convert_image, SequenceTypes
+from string import uppercase, lowercase
+
+from ..api import BaseTraitHandler, CTrait, Enum, TraitError
+
+from .ui_traits import SequenceTypes
 
-    
 #-------------------------------------------------------------------------------
-#  Trait definitions:  
+#  Trait definitions:
 #-------------------------------------------------------------------------------
 
 # Layout orientation for a control and its associated editor
@@ -62,7 +58,7 @@ def user_name_for ( name ):
         last_lower = (c in lowercase)
         result    += c
     return result
-    
+
 #-------------------------------------------------------------------------------
 #  Format a number with embedded commas:
 #-------------------------------------------------------------------------------
@@ -76,19 +72,17 @@ def commatize ( value ):
     result = ','.join( [ s[ i: i+3 ] for i in range( 0, len(s), 3 ) ] ).lstrip()
     if value >= 0:
         return result
-        
+
     return '-' + result
 
-
-    
 #-------------------------------------------------------------------------------
 #  Recomputes the mappings for a new set of enumeration values:
 #-------------------------------------------------------------------------------
- 
+
 def enum_values_changed ( values ):
     """ Recomputes the mappings for a new set of enumeration values.
     """
-    
+
     if isinstance( values, dict ):
         data = [ ( unicode( v ), n ) for n, v in values.items() ]
         if len( data ) > 0:
@@ -109,12 +103,12 @@ def enum_values_changed ( values ):
             data = [ ( unicode( v ), v ) for v in handler.values ]
     else:
         data = [ ( unicode( v ), v ) for v in values ]
-    
+
     names           = [ x[0] for x in data ]
     mapping         = {}
     inverse_mapping = {}
     for name, value in data:
         mapping[ name ] = value
         inverse_mapping[ value ] = name
-        
-    return ( names, mapping, inverse_mapping )  
+
+    return ( names, mapping, inverse_mapping )
